Tasty Tag Model

# Tag Model

the core resources are Services, Users, Items, and Tags.

the Service resource exists primarily as a form of namespacing. it allows multiple applications to use the same tag server without stomping on each others' data. all points within an application that access the tag server should use the same Service. the service MUST always be specified in every request URI.

the Users, Items, and Tags use the model described on tagschema.com.